summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorNikolay Zamotaev <nzamotaev@luxoft.com>2018-06-20 17:43:05 +0300
committerNikolay Zamotaev <nzamotaev@luxoft.com>2018-06-22 14:47:40 +0000
commitfec257d2497ecaff5aa8071cc122b4cc8144caa3 (patch)
tree53c46d0516720e741bf693f1fecea4d36ce3ffb4
parent86a6be432c34977483f384c1e05d3945c6a40b5a (diff)
[deployment-server] Renamed appstore to deployment server
Change-Id: Id6225825f4a3498e16d8028c4560223704c1986c Reviewed-by: Dominik Holland <dominik.holland@pelagicore.com>
-rw-r--r--README.md6
-rw-r--r--appstore/settings.py4
-rw-r--r--appstore/urls.py2
-rw-r--r--appstore/wsgi.py4
-rw-r--r--header.GPL-QTAS2
-rw-r--r--manage.py2
-rw-r--r--store/admin.py2
-rw-r--r--store/api.py2
-rw-r--r--store/management/commands/expire-downloads.py2
-rw-r--r--store/management/commands/store-sign-package.py2
-rw-r--r--store/management/commands/verify-upload-package.py2
-rw-r--r--store/migrations/0001_initial.py2
-rw-r--r--store/models.py2
-rw-r--r--store/utilities.py2
14 files changed, 18 insertions, 18 deletions
diff --git a/README.md b/README.md
index a5c0fd2..9c32719 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-This is a PoC appstore server, which can be used together with
+This is a PoC deployment server, which can be used together with
the Neptune IVI UI and the Pelagicore Application Manager.
**This is a development server only - do NOT use in production.**
@@ -72,7 +72,7 @@ Commands
HTTP API
========
-The appstore server exposes a HTTP API to the world. Arguments to the
+The deployment server exposes a HTTP API to the world. Arguments to the
functions need to be provided using the HTTP GET syntax. The returned data
will be JSON, PNG or text, depending on the function
@@ -138,7 +138,7 @@ Checks whether you are using the right Platform and the right API to communicate
| Parameter | Description |
| ---------- | ----------- |
| `platform` | The platform the client is running on, this sets the architecture of the packages you get. (see `settings.APPSTORE_PLATFORM`) |
-| `version` | The Appstore Server HTTP API version you are using to communicate with the server. (see `settings.APPSTORE_VERSION`) |
+| `version` | The Deployment Server HTTP API version you are using to communicate with the server. (see `settings.APPSTORE_VERSION`) |
Returns a JSON object:
diff --git a/appstore/urls.py b/appstore/urls.py
index 333158a..5e4e708 100644
--- a/appstore/urls.py
+++ b/appstore/urls.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/header.GPL-QTAS b/header.GPL-QTAS
index 587eb10..0bd19ca 100644
--- a/header.GPL-QTAS
+++ b/header.GPL-QTAS
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/manage.py b/manage.py
index 14b9b10..bd587ad 100644
--- a/manage.py
+++ b/manage.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/admin.py b/store/admin.py
index 7eb07a1..db2672b 100644
--- a/store/admin.py
+++ b/store/admin.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/api.py b/store/api.py
index 6a8b8dc..5e1620e 100644
--- a/store/api.py
+++ b/store/api.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/management/commands/expire-downloads.py b/store/management/commands/expire-downloads.py
index ab78f11..edc5235 100644
--- a/store/management/commands/expire-downloads.py
+++ b/store/management/commands/expire-downloads.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/management/commands/store-sign-package.py b/store/management/commands/store-sign-package.py
index be82fc5..479b4c4 100644
--- a/store/management/commands/store-sign-package.py
+++ b/store/management/commands/store-sign-package.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/management/commands/verify-upload-package.py b/store/management/commands/verify-upload-package.py
index c505166..87ac08a 100644
--- a/store/management/commands/verify-upload-package.py
+++ b/store/management/commands/verify-upload-package.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/migrations/0001_initial.py b/store/migrations/0001_initial.py
index 4142c6d..3c85e9d 100644
--- a/store/migrations/0001_initial.py
+++ b/store/migrations/0001_initial.py
@@ -4,7 +4,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/models.py b/store/models.py
index d62ae6a..4d87f70 100644
--- a/store/models.py
+++ b/store/models.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/store/utilities.py b/store/utilities.py
index e971482..1b68f6a 100644
--- a/store/utilities.py
+++ b/store/utilities.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
diff --git a/appstore/settings.py b/appstore/settings.py
index f3bb472..83ca6d7 100644
--- a/appstore/settings.py
+++ b/appstore/settings.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
## This file is part of the Neptune AppStore Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
@@ -30,7 +30,7 @@
#############################################################################
"""
-Django settings for appstore project.
+Django settings for deployment server project.
For more information on this file, see
https://docs.djangoproject.com/en/1.7/topics/settings/
@@ -3,7 +3,7 @@
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
diff --git a/appstore/wsgi.py b/appstore/wsgi.py
index 8e38982..9e80014 100644
--- a/appstore/wsgi.py
+++ b/appstore/wsgi.py
@@ -3,7 +3,7 @@
## Copyright (C) 2016 Pelagicore AG
## Contact: https://www.qt.io/licensing/
##
## This file is part of the Neptune AppStore Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$
## Commercial License Usage
@@ -30,7 +30,7 @@
#############################################################################
"""
-WSGI config for appstore project.
+WSGI config for deployment server project.
It exposes the WSGI callable as a module-level variable named ``application``.
@@ -3,7 +3,7 @@
## Contact: https://www.qt.io/licensing/
##
-## This file is part of the Neptune AppStore Server
+## This file is part of the Neptune Deployment Server
##
## $QT_BEGIN_LICENSE:GPL-QTAS$